PooledConnection class abstract

Constructors

PooledConnection()

Properties

backendPid → int?
The pid of the postgresql handler.
no setter
connectionState → ConnectionState?
no setter
established → DateTime?
Time at which the physical connection to the database was established.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isLeaked → bool
If a leak detection threshold is set, then this flag will be set on leaked connections.
no setter
name → String
no setter
obtained → DateTime?
Time at which the connection was last obtained by a client.
no setter
released → DateTime?
Time at which the connection was last released by a client.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stacktrace at the time pool.connect() was last called.
no setter
state → PooledConnectionState?
The state of connection in the pool: available, closed, etc.
no setter
useId → int?
A unique id that updated whenever the connection is obtained.
no setter

Methods

destroy() → void
Destroys the pooled connection: physically closes it, removes it from the pool, and replenishes toward minConnections. Safe to call multiple times (a second call is a no-op).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited