ClientMessage class abstract

An error or warning generated by the client.

Implemented types

Constructors

ClientMessage({bool isError, required String severity, required String message, String? connectionName, Object? exception, StackTrace? stackTrace})
factory

Properties

connectionName → String?
An identifier for the connection. Useful for logging messages in a connection pool.
no setterinherited
exception → Object?
no setter
hashCode → int
The hash code for this object.
no setterinherited
isError → bool
Returns true if this is an error, otherwise it is a server-side notice, or logging.
no setterinherited
message → String
A human readible error message, typically one line.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → String?
For a ServerMessage from an English localized database the field contents are ERROR, FATAL, or PANIC, for an error message. Otherwise in a notice message they are WARNING, NOTICE, DEBUG, INFO, or LOG.
no setterinherited
stackTrace → StackTrace?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited