Column class abstract

Constructors

Column()

Properties

dataSize → int
no setter
fieldId → int
no setter
fieldType → int
no setter
formatCode → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
no setter
isBinary → bool
no setter
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableColNo → int
no setter
typeModifier → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited