Connection class abstract
A connection to a PostgreSQL database.
Constructors
Properties
- backendPid → int?
-
The pid of the process the server started to handle this connection.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
→ Stream<
Message> -
The server can send errors and notices, or the network can cause errors
while the connection is not being used to make a query. These can be
caught by listening to the messages stream. See ClientMessage and
ServerMessage for more information.
no setter
-
parameters
→ Map<
String, String> -
Server configuration parameters such as date format and timezone.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → ConnectionState
-
The current state of the connection.
no setter
- transactionState → TransactionState
-
The state of the current transaction.
no setter
Methods
-
close(
) → void - Close the current Connection. It is safe to call this multiple times. This will never throw an exception.
-
destroy(
) → void -
Destroys the connection. Unlike close, a pooled connection is
physically closed, so session state (e.g. a session-level
SET) won't leak to the next borrower. Safe to call multiple times. -
execute(
String sql, [Map? values]) → Future< int> - Queues a command for execution, and when done, returns the number of rows affected by the sql command. Indentical to query apart from the information returned.
-
executeByList(
String sql, List values) → Future< int> - Queues a command for execution, and when done, returns the number of rows affected by the sql command. Indentical to queryByList apart from the information returned. If there are no values to substitute, use execute instead.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
String sql, [Map? values]) → Stream< Row> - Queue a sql query to be run, returning a Stream of Rows.
-
queryByList(
String sql, List values) → Stream< Row> -
Queue a sql query to be run, returning a Stream of Rows.
The results can be fetched from the Rows by index.
Identical to query apart from the
valuesmust be a list. If there are no values to substitute, use query instead. -
runInTransaction<
T> (Future< T> operation(), [Isolation isolation]) → Future<T> - Allow multiple queries to be run in a transaction. The user must wait for runInTransaction() to complete before making any further queries.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited