executeByList abstract method
Queues a command for execution, and when done, returns the number of rows affected by the sql command. Indentical to queryByList apart from the information returned. If there are no values to substitute, use execute instead.
Implementation
Future<int> executeByList(String sql, List values);