queryByList abstract method
Queue a sql query to be run, returning a Stream of Rows.
The results can be fetched from the Rows by index.
Identical to query apart from the values must be a list.
If there are no values to substitute, use query instead.
For example:
conn.queryByList("insert into foo_table values (@0, @1);", [a, b])
.then(...);
Implementation
Stream<Row> queryByList(String sql, List values);