DefaultTypeConverter class

Implemented types

Constructors

DefaultTypeConverter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(String value, int pgType, {String? connectionName}) → Object?
Convert a string recieved from the database into a dart object. Null if it decodes to null, e.g. the json scalar null (a SQL null never gets here).
override
decodeArray(String value, int pgType, {String? connectionName}) → dynamic
Decodes an array value, value, into a flat List. Each item is decoded as pgType.
decodeDateTime(String value, int pgType, {String? connectionName}) → DateTime
Decodes value into a DateTime instance.
decodeValue(String value, int pgType, {String? connectionName}) → dynamic
encode(dynamic value, String? type, {String? connectionName}) → String
Convert an object to a string representation to use in a sql query. Be very careful to escape your strings correctly. If you get this wrong you will introduce a sql injection vulnerability. Consider using the provided encodeString function.
override
encodeArray(Iterable value, {String? pgType}) → String
encodeBytea(Iterable<int> value) → String
encodeDateTime(DateTime? datetime, {bool isDateOnly = false}) → String
encodeJson(dynamic value) → String
encodeNumber(num n) → String
encodeValue(dynamic value, String? type, {String? connectionName}) → String
encodeValueDefault(dynamic value, {String? connectionName}) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited