PostgresqlException class

Implemented types

Constructors

PostgresqlException(String message, String? connectionName, {ServerMessage? serverMessage, Object? exception})

Properties

connectionName → String?
Note the connection name can be null in some cases when thrown by pool.
final
exception → Object?
Note may be null.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverMessage → ServerMessage?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited