Row class abstract

Row allows field values to be retrieved as if they were getters.

c.query("select 'blah' as my_field")
   .single
   .then((row) => print(row.my_field));

Or by index.

c.query("select 'blah'")
   .single
   .then((row) => print(row[0]));

Constructors

Row()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

forEach(void f(String columnName, dynamic columnValue)) → void
Iterate through column names and values.
getColumns() → List<Column>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toList() → List
An unmodifiable list of column values.
toMap() → Map<String, dynamic>
An unmodifiable map of column names and values.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int i) → dynamic
Get a column value by column index (zero based).