ServerMessage class abstract

Represents an error or a notice sent from the postgresql server.

Implemented types

Constructors

ServerMessage()

Properties

code → String?
A PostgreSQL error code. See http://www.postgresql.org/docs/9.2/static/errcodes-appendix.html
no setter
column → String?
no setter
connectionName → String?
An identifier for the connection. Useful for logging messages in a connection pool.
no setteroverride
constraint → String?
no setter
dataType → String?
no setter
detail → String?
More detailed information.
no setter
fields → Map<String, String>
All of the information returned from the server.
no setter
file → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
hint → String?
no setter
internalPosition → String?
no setter
internalQuery → String?
no setter
isError → bool
Returns true if this is an error, otherwise it is a server-side notice.
no setteroverride
line → String?
no setter
message → String
A human readible error message, typically one line.
no setteroverride
position → String?
The position as an index into the original query string where the syntax error was found. The first character has index 1, and positions are measured in characters not bytes. If the server does not supply a position this field is null.
no setter
routine → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String?
no setter
severity → String?
For a ServerMessage from an English localized database the field contents are ERROR, FATAL, or PANIC, for an error message. Otherwise in a notice message they are WARNING, NOTICE, DEBUG, INFO, or LOG.
no setteroverride
table → String?
no setter
where → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited