Settings class abstract

Settings can be used to create a postgresql uri for use in the connect function.

Constructors

Settings(String host, int port, String user, String password, String database, {bool requireSsl})
factory
Settings.fromUri(String uri)
Parse a PostgreSQL URI string.
factory

Properties

database → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
host → String
no setter
password → String
no setter
port → int
no setter
requireSsl → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toUri() → String
Return a connection URI.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultPort → const int
The default port used by a PostgreSQL server.